"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.serverless.workflows.v1.execution_pb2
import yandex.cloud.serverless.workflows.v1.history_entry_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class StartExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    @property
    def input(self) -> yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionInput:
        """Input for the Workflow execution"""

    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        input: yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["input", b"input", "workflow_id", b"workflow_id"]) -> None: ...

global___StartExecutionRequest = StartExecutionRequest

@typing.final
class StartExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___StartExecutionResponse = StartExecutionResponse

@typing.final
class StopExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___StopExecutionRequest = StopExecutionRequest

@typing.final
class StopExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___StopExecutionResponse = StopExecutionResponse

@typing.final
class GetExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionRequest = GetExecutionRequest

@typing.final
class GetExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_FIELD_NUMBER: builtins.int
    @property
    def execution(self) -> yandex.cloud.serverless.workflows.v1.execution_pb2.Execution:
        """Workflow execution details."""

    def __init__(
        self,
        *,
        execution: yandex.cloud.serverless.workflows.v1.execution_pb2.Execution | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["execution", b"execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution", b"execution"]) -> None: ...

global___GetExecutionResponse = GetExecutionResponse

@typing.final
class GetExecutionHistoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionHistoryRequest = GetExecutionHistoryRequest

@typing.final
class GetExecutionHistoryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def execution(self) -> yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview:
        """Workflow execution details."""

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.workflows.v1.history_entry_pb2.HistoryEntry]:
        """Workflow execution detailed history items."""

    def __init__(
        self,
        *,
        execution: yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview | None = ...,
        entries: collections.abc.Iterable[yandex.cloud.serverless.workflows.v1.history_entry_pb2.HistoryEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["execution", b"execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["entries", b"entries", "execution", b"execution"]) -> None: ...

global___GetExecutionHistoryResponse = GetExecutionHistoryResponse

@typing.final
class ListExecutionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListExecutionsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListExecutionsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the following fields: status, started_at, finished_at.
    2. Operator: `=`, `<` or `>`.
    3. The value. Must be sting and match the regular expression `[+:\\.-a-z0-9]`.
    Examples of a filter: `status=ERROR`, `created_by=John.Doe`.
    """
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "workflow_id", b"workflow_id"]) -> None: ...

global___ListExecutionsRequest = ListExecutionsRequest

@typing.final
class ListExecutionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListExecutionsRequest.page_size], use `next_page_token` as the value
    for the [ListExecutionsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def executions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview]:
        """List of Workflow executions."""

    def __init__(
        self,
        *,
        executions: collections.abc.Iterable[yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["executions", b"executions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListExecutionsResponse = ListExecutionsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.speechsense.v1.analysis.predefined_classifiers_pb2
import yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Transcription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHRASES_FIELD_NUMBER: builtins.int
    ALGORITHMS_METADATA_FIELD_NUMBER: builtins.int
    @property
    def phrases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Phrase]: ...
    @property
    def algorithms_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlgorithmMetadata]:
        """Their might be several algorithms that work on talk transcription. For example: speechkit and translator
        So there might be other fields here for tracing
        """

    def __init__(
        self,
        *,
        phrases: collections.abc.Iterable[global___Phrase] | None = ...,
        algorithms_metadata: collections.abc.Iterable[global___AlgorithmMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["algorithms_metadata", b"algorithms_metadata", "phrases", b"phrases"]) -> None: ...

global___Transcription = Transcription

@typing.final
class Phrase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    START_TIME_MS_FIELD_NUMBER: builtins.int
    END_TIME_MS_FIELD_NUMBER: builtins.int
    PHRASE_FIELD_NUMBER: builtins.int
    STATISTICS_FIELD_NUMBER: builtins.int
    CLASSIFIERS_FIELD_NUMBER: builtins.int
    channel_number: builtins.int
    start_time_ms: builtins.int
    end_time_ms: builtins.int
    @property
    def phrase(self) -> global___PhraseText: ...
    @property
    def statistics(self) -> global___PhraseStatistics: ...
    @property
    def classifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.analysis.predefined_classifiers_pb2.RecognitionClassifierResult]: ...
    def __init__(
        self,
        *,
        channel_number: builtins.int = ...,
        start_time_ms: builtins.int = ...,
        end_time_ms: builtins.int = ...,
        phrase: global___PhraseText | None = ...,
        statistics: global___PhraseStatistics | None = ...,
        classifiers: collections.abc.Iterable[yandex.cloud.speechsense.v1.analysis.predefined_classifiers_pb2.RecognitionClassifierResult] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["phrase", b"phrase", "statistics", b"statistics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_number", b"channel_number", "classifiers", b"classifiers", "end_time_ms", b"end_time_ms", "phrase", b"phrase", "start_time_ms", b"start_time_ms", "statistics", b"statistics"]) -> None: ...

global___Phrase = Phrase

@typing.final
class PhraseText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    NORMALIZED_TEXT_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    text: builtins.str
    language: builtins.str
    normalized_text: builtins.str
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Word]: ...
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        language: builtins.str = ...,
        normalized_text: builtins.str = ...,
        words: collections.abc.Iterable[global___Word] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["language", b"language", "normalized_text", b"normalized_text", "text", b"text", "words", b"words"]) -> None: ...

global___PhraseText = PhraseText

@typing.final
class Word(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORD_FIELD_NUMBER: builtins.int
    START_TIME_MS_FIELD_NUMBER: builtins.int
    END_TIME_MS_FIELD_NUMBER: builtins.int
    word: builtins.str
    start_time_ms: builtins.int
    end_time_ms: builtins.int
    def __init__(
        self,
        *,
        word: builtins.str = ...,
        start_time_ms: builtins.int = ...,
        end_time_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_time_ms", b"end_time_ms", "start_time_ms", b"start_time_ms", "word", b"word"]) -> None: ...

global___Word = Word

@typing.final
class AlgorithmMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_TASK_DATE_FIELD_NUMBER: builtins.int
    COMPLETED_TASK_DATE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    trace_id: builtins.str
    name: builtins.str
    @property
    def created_task_date(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def completed_task_date(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def error(self) -> global___Error: ...
    def __init__(
        self,
        *,
        created_task_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        completed_task_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        error: global___Error | None = ...,
        trace_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completed_task_date", b"completed_task_date", "created_task_date", b"created_task_date", "error", b"error"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["completed_task_date", b"completed_task_date", "created_task_date", b"created_task_date", "error", b"error", "name", b"name", "trace_id", b"trace_id"]) -> None: ...

global___AlgorithmMetadata = AlgorithmMetadata

@typing.final
class Error(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    code: builtins.str
    message: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "message", b"message"]) -> None: ...

global___Error = Error

@typing.final
class PhraseStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATISTICS_FIELD_NUMBER: builtins.int
    @property
    def statistics(self) -> yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2.UtteranceStatistics: ...
    def __init__(
        self,
        *,
        statistics: yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2.UtteranceStatistics | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["statistics", b"statistics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["statistics", b"statistics"]) -> None: ...

global___PhraseStatistics = PhraseStatistics



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/snapshot_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/compute/v1/snapshot_schedule.proto\x12\x17yandex.cloud.compute.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x05\n\x10SnapshotSchedule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32\x35.yandex.cloud.compute.v1.SnapshotSchedule.LabelsEntry\x12@\n\x06status\x18\x07 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.SnapshotSchedule.Status\x12@\n\x0fschedule_policy\x18\x08 \x01(\x0b\x32\'.yandex.cloud.compute.v1.SchedulePolicy\x12\x35\n\x10retention_period\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x18\n\x0esnapshot_count\x18\n \x01(\x03H\x00\x12<\n\rsnapshot_spec\x18\x0b \x01(\x0b\x32%.yandex.cloud.compute.v1.SnapshotSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x42\x12\n\x10retention_policy\"R\n\x0eSchedulePolicy\x12,\n\x08start_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nexpression\x18\x02 \x01(\t\"\x95\x01\n\x0cSnapshotSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.yandex.cloud.compute.v1.SnapshotSpec.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.snapshot_schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _SNAPSHOTSCHEDULE_LABELSENTRY._options = None
  _SNAPSHOTSCHEDULE_LABELSENTRY._serialized_options = b'8\001'
  _SNAPSHOTSPEC_LABELSENTRY._options = None
  _SNAPSHOTSPEC_LABELSENTRY._serialized_options = b'8\001'
  _globals['_SNAPSHOTSCHEDULE']._serialized_start=142
  _globals['_SNAPSHOTSCHEDULE']._serialized_end=789
  _globals['_SNAPSHOTSCHEDULE_LABELSENTRY']._serialized_start=622
  _globals['_SNAPSHOTSCHEDULE_LABELSENTRY']._serialized_end=667
  _globals['_SNAPSHOTSCHEDULE_STATUS']._serialized_start=669
  _globals['_SNAPSHOTSCHEDULE_STATUS']._serialized_end=769
  _globals['_SCHEDULEPOLICY']._serialized_start=791
  _globals['_SCHEDULEPOLICY']._serialized_end=873
  _globals['_SNAPSHOTSPEC']._serialized_start=876
  _globals['_SNAPSHOTSPEC']._serialized_end=1025
  _globals['_SNAPSHOTSPEC_LABELSENTRY']._serialized_start=622
  _globals['_SNAPSHOTSPEC_LABELSENTRY']._serialized_end=667
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AuthSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAML_FIELD_NUMBER: builtins.int
    @property
    def saml(self) -> global___SAMLSettings:
        """SAML settings"""

    def __init__(
        self,
        *,
        saml: global___SAMLSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["saml", b"saml"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["saml", b"saml"]) -> None: ...

global___AuthSettings = AuthSettings

@typing.final
class SAMLSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    IDP_ENTITY_ID_FIELD_NUMBER: builtins.int
    IDP_METADATA_FILE_FIELD_NUMBER: builtins.int
    SP_ENTITY_ID_FIELD_NUMBER: builtins.int
    DASHBOARDS_URL_FIELD_NUMBER: builtins.int
    ROLES_KEY_FIELD_NUMBER: builtins.int
    SUBJECT_KEY_FIELD_NUMBER: builtins.int
    JWT_DEFAULT_EXPIRATION_TIMEOUT_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    idp_entity_id: builtins.str
    """Required. The entity ID of your IdP."""
    idp_metadata_file: builtins.bytes
    """Required. The SAML 2.0 metadata file of your IdP."""
    sp_entity_id: builtins.str
    """Required. The entity ID of the service provider."""
    dashboards_url: builtins.str
    """Required. The OpenSearch Dashboards base URL."""
    roles_key: builtins.str
    """Optional. The attribute in the SAML response where the roles are stored. If not configured, no roles are used."""
    subject_key: builtins.str
    """Optional. The attribute in the SAML response where the subject is stored. If not configured, the NameID attribute is used."""
    @property
    def jwt_default_expiration_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """default jwt expiration timeout."""

    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        idp_entity_id: builtins.str = ...,
        idp_metadata_file: builtins.bytes = ...,
        sp_entity_id: builtins.str = ...,
        dashboards_url: builtins.str = ...,
        roles_key: builtins.str = ...,
        subject_key: builtins.str = ...,
        jwt_default_expiration_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["jwt_default_expiration_timeout", b"jwt_default_expiration_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dashboards_url", b"dashboards_url", "enabled", b"enabled", "idp_entity_id", b"idp_entity_id", "idp_metadata_file", b"idp_metadata_file", "jwt_default_expiration_timeout", b"jwt_default_expiration_timeout", "roles_key", b"roles_key", "sp_entity_id", b"sp_entity_id", "subject_key", b"subject_key"]) -> None: ...

global___SAMLSettings = SAMLSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Zone(google.protobuf.message.Message):
    """Availability zone. For more information, see [Availability zones](/docs/overview/concepts/geo-scope)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Zone._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Zone._Status.ValueType  # 0
        UP: Zone._Status.ValueType  # 1
        """Zone is available. You can access the resources allocated in this zone."""
        DOWN: Zone._Status.ValueType  # 2
        """Zone is not available."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Zone.Status.ValueType  # 0
    UP: Zone.Status.ValueType  # 1
    """Zone is available. You can access the resources allocated in this zone."""
    DOWN: Zone.Status.ValueType  # 2
    """Zone is not available."""

    ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the zone."""
    region_id: builtins.str
    """ID of the region."""
    status: global___Zone.Status.ValueType
    """Status of the zone."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        region_id: builtins.str = ...,
        status: global___Zone.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "region_id", b"region_id", "status", b"status"]) -> None: ...

global___Zone = Zone



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ResourceType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResourceType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESOURCE_TYPE_UNSPECIFIED: _ResourceType.ValueType  # 0
    RESOURCE_TYPE_SECRET: _ResourceType.ValueType  # 2
    RESOURCE_TYPE_DOCKER_IMAGE: _ResourceType.ValueType  # 3
    RESOURCE_TYPE_DATASET: _ResourceType.ValueType  # 4
    RESOURCE_TYPE_S3: _ResourceType.ValueType  # 5
    RESOURCE_TYPE_NODE: _ResourceType.ValueType  # 6
    RESOURCE_TYPE_ALIAS: _ResourceType.ValueType  # 8

class ResourceType(_ResourceType, metaclass=_ResourceTypeEnumTypeWrapper): ...

RESOURCE_TYPE_UNSPECIFIED: ResourceType.ValueType  # 0
RESOURCE_TYPE_SECRET: ResourceType.ValueType  # 2
RESOURCE_TYPE_DOCKER_IMAGE: ResourceType.ValueType  # 3
RESOURCE_TYPE_DATASET: ResourceType.ValueType  # 4
RESOURCE_TYPE_S3: ResourceType.ValueType  # 5
RESOURCE_TYPE_NODE: ResourceType.ValueType  # 6
RESOURCE_TYPE_ALIAS: ResourceType.ValueType  # 8
global___ResourceType = ResourceType



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import group_mapping_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2


class GroupMappingServiceStub(object):
    """RPC service dedicated for federation group mapping.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupMappingService/Get',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.GetGroupMappingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.GetGroupMappingResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupMappingService/Create',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.CreateGroupMappingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupMappingService/Update',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.UpdateGroupMappingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupMappingService/Delete',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.DeleteGroupMappingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListItems = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupMappingService/ListItems',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.ListGroupMappingItemsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.ListGroupMappingItemsResponse.FromString,
                )
        self.UpdateItems = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupMappingService/UpdateItems',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.UpdateGroupMappingItemsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class GroupMappingServiceServicer(object):
    """RPC service dedicated for federation group mapping.
    """

    def Get(self, request, context):
        """Returns a group mapping configured for the specific federation
        If a federation does not exist this call will return an error
        NOT_FOUND will be returned
        If a federation exist, but has not ever been configured for group mapping
        the call FAILED_PRECONDITION will be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Adds a group mapping for a federation
        If mapping already exist, ALREADY_EXISTS will be returned
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an existing group mapping for a federation
        Errors:
        - if federation is not found
        In case of any error, no changes are applied to existing group mapping

        This call is idempotent. The following actions do nothing:
        - enabling when already enabled
        - disabling when disabled
        Such parts of request will be ignored. Others will be applied.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a group mapping. This will remove all the mapping items
        cascade.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListItems(self, request, context):
        """Returns all the group mappings items

        Filtering is only supported by external_group_id or internal_group_id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateItems(self, request, context):
        """Updates group mapping items for a specified federation
        Errors:
        - if federation is not found
        - if internal group in the mapping added does not exist
        In case of any error, no changes are applied to existing group mapping

        This call is idempotent. The following actions do nothing:
        - adding group mapping items that are already present
        - removing group mapping items that are not present
        Such parts of request will be ignored. Others will be applied.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupMappingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.GetGroupMappingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.GetGroupMappingResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.CreateGroupMappingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.UpdateGroupMappingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.DeleteGroupMappingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListItems': grpc.unary_unary_rpc_method_handler(
                    servicer.ListItems,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.ListGroupMappingItemsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.ListGroupMappingItemsResponse.SerializeToString,
            ),
            'UpdateItems': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateItems,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.UpdateGroupMappingItemsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.GroupMappingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GroupMappingService(object):
    """RPC service dedicated for federation group mapping.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.GroupMappingService/Get',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.GetGroupMappingRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.GetGroupMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.GroupMappingService/Create',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.CreateGroupMappingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.GroupMappingService/Update',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.UpdateGroupMappingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.GroupMappingService/Delete',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.DeleteGroupMappingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListItems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.GroupMappingService/ListItems',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.ListGroupMappingItemsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.ListGroupMappingItemsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateItems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.GroupMappingService/UpdateItems',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__service__pb2.UpdateGroupMappingItemsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.clickhouse.v1.format_schema_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFormatSchemaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FORMAT_SCHEMA_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID.

    To get a ClickHouse cluster ID, use the [ClusterService.List] method.
    """
    format_schema_name: builtins.str
    """Format schema name.

    To get a format schema name, use the [FormatSchemaService.List] method.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        format_schema_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "format_schema_name", b"format_schema_name"]) -> None: ...

global___GetFormatSchemaRequest = GetFormatSchemaRequest

@typing.final
class ListFormatSchemasRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID.

    To get a ClickHouse cluster ID, use the [ClusterService.List] method.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of the results is larger than [page_size], the service returns [ListFormatSchemasResponse.next_page_token]. You can use it to get the next page of the results in subsequent requests of a format schema list."""
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListFormatSchemasResponse.next_page_token] returned by the previous format schema list request."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFormatSchemasRequest = ListFormatSchemasRequest

@typing.final
class ListFormatSchemasResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORMAT_SCHEMAS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results when requesting the format schema list. If the number of the results is larger than [ListFormatSchemasRequest.page_size], use the [next_page_token] as the value for the [ListFormatSchemasRequest.page_token] parameter in the next request. Each subsequent request will have its own [next_page_token] to continue paging through the results."""
    @property
    def format_schemas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema]:
        """List of format schemas."""

    def __init__(
        self,
        *,
        format_schemas: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["format_schemas", b"format_schemas", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFormatSchemasResponse = ListFormatSchemasResponse

@typing.final
class CreateFormatSchemaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FORMAT_SCHEMA_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID.

    To get a ClickHouse cluster ID, use the [ClusterService.List] method.
    """
    format_schema_name: builtins.str
    """Format schema name."""
    type: yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchemaType.ValueType
    """Schema type. Possible values are the following:

    * FORMAT_SCHEMA_TYPE_PROTOBUF - [Protobuf](https://protobuf.dev/) data format (including [ProtobufSingle](https://clickhouse.com/docs/en/interfaces/formats#protobufsingle)).
    * FORMAT_SCHEMA_TYPE_CAPNPROTO - [Cap'n Proto](https://capnproto.org/) data format.
    """
    uri: builtins.str
    """[Link to the file](/docs/managed-clickhouse/operations/s3-access#get-link-to-object) of a format schema in Yandex Object Storage. Managed Service for ClickHouse works only with format schemas imported to Object Storage."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        format_schema_name: builtins.str = ...,
        type: yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchemaType.ValueType = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "format_schema_name", b"format_schema_name", "type", b"type", "uri", b"uri"]) -> None: ...

global___CreateFormatSchemaRequest = CreateFormatSchemaRequest

@typing.final
class CreateFormatSchemaMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FORMAT_SCHEMA_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID."""
    format_schema_name: builtins.str
    """Format schema name."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        format_schema_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "format_schema_name", b"format_schema_name"]) -> None: ...

global___CreateFormatSchemaMetadata = CreateFormatSchemaMetadata

@typing.final
class UpdateFormatSchemaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FORMAT_SCHEMA_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID.

    To get a ClickHouse cluster ID, use the [ClusterService.List] method.
    """
    format_schema_name: builtins.str
    """Format schema name.

    To get a format schema name, use the [FormatSchemaService.List] method.
    """
    uri: builtins.str
    """[Link to the file](/docs/managed-clickhouse/operations/s3-access#get-link-to-object) of a format schema in Yandex Object Storage. Managed Service for ClickHouse works only with format schemas imported to Object Storage."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        format_schema_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "format_schema_name", b"format_schema_name", "update_mask", b"update_mask", "uri", b"uri"]) -> None: ...

global___UpdateFormatSchemaRequest = UpdateFormatSchemaRequest

@typing.final
class UpdateFormatSchemaMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FORMAT_SCHEMA_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID."""
    format_schema_name: builtins.str
    """Format schema name."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        format_schema_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "format_schema_name", b"format_schema_name"]) -> None: ...

global___UpdateFormatSchemaMetadata = UpdateFormatSchemaMetadata

@typing.final
class DeleteFormatSchemaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FORMAT_SCHEMA_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID.

    To get a ClickHouse cluster ID, use the [ClusterService.List] method.
    """
    format_schema_name: builtins.str
    """Format schema name.

    To get a format schema name, use the [FormatSchemaService.List] method.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        format_schema_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "format_schema_name", b"format_schema_name"]) -> None: ...

global___DeleteFormatSchemaRequest = DeleteFormatSchemaRequest

@typing.final
class DeleteFormatSchemaMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FORMAT_SCHEMA_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ClickHouse cluster ID."""
    format_schema_name: builtins.str
    """Format schema name."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        format_schema_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "format_schema_name", b"format_schema_name"]) -> None: ...

global___DeleteFormatSchemaMetadata = DeleteFormatSchemaMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/subnet_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.reference import reference_pb2 as yandex_dot_cloud_dot_reference_dot_reference__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.vpc.v1 import subnet_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/vpc/v1/subnet_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a&yandex/cloud/reference/reference.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/vpc/v1/subnet.proto\"3\n\x10GetSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8f\x01\n\x12ListSubnetsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\\\n\x13ListSubnetsResponse\x12,\n\x07subnets\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.vpc.v1.Subnet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x86\x04\n\x13\x43reateSubnetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x04name\x18\x02 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x81\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.vpc.v1.CreateSubnetRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12 \n\nnetwork_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x07zone_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x0ev4_cidr_blocks\x18\x07 \x03(\tB\x04\xe8\xc7\x31\x01\x12 \n\x0eroute_table_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x36\n\x0c\x64hcp_options\x18\n \x01(\x0b\x32 .yandex.cloud.vpc.v1.DhcpOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x08\x10\t\")\n\x14\x43reateSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"\xea\x03\n\x13UpdateSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04name\x18\x03 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x81\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x34.yandex.cloud.vpc.v1.UpdateSubnetRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12 \n\x0eroute_table_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x36\n\x0c\x64hcp_options\x18\x07 \x01(\x0b\x32 .yandex.cloud.vpc.v1.DhcpOptions\x12\x16\n\x0ev4_cidr_blocks\x18\x08 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"U\n\x1a\x41\x64\x64SubnetCidrBlocksRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0ev4_cidr_blocks\x18\x02 \x03(\t\"0\n\x1b\x41\x64\x64SubnetCidrBlocksMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"X\n\x1dRemoveSubnetCidrBlocksRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0ev4_cidr_blocks\x18\x02 \x03(\t\"3\n\x1eRemoveSubnetCidrBlocksMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"|\n\x1bListSubnetOperationsRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1cListSubnetOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"a\n\x11MoveSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x12MoveSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"j\n\x18ListUsedAddressesRequest\x12\x17\n\tsubnet_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"i\n\x19ListUsedAddressesResponse\x12\x33\n\taddresses\x18\x01 \x03(\x0b\x32 .yandex.cloud.vpc.v1.UsedAddress\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x89\x01\n\x0bUsedAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x32\n\nip_version\x18\x02 \x01(\x0e\x32\x1e.yandex.cloud.vpc.v1.IpVersion\x12\x35\n\nreferences\x18\x03 \x03(\x0b\x32!.yandex.cloud.reference.Reference\"[\n\x15RelocateSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x13\x64\x65stination_zone_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x16RelocateSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t2\x80\x0e\n\rSubnetService\x12n\n\x03Get\x12%.yandex.cloud.vpc.v1.GetSubnetRequest\x1a\x1b.yandex.cloud.vpc.v1.Subnet\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/vpc/v1/subnets/{subnet_id}\x12r\n\x04List\x12\'.yandex.cloud.vpc.v1.ListSubnetsRequest\x1a(.yandex.cloud.vpc.v1.ListSubnetsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/vpc/v1/subnets\x12\x93\x01\n\x06\x43reate\x12(.yandex.cloud.vpc.v1.CreateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"<\xb2\xd2*\x1e\n\x14\x43reateSubnetMetadata\x12\x06Subnet\x82\xd3\xe4\x93\x02\x14\"\x0f/vpc/v1/subnets:\x01*\x12\x9f\x01\n\x06Update\x12(.yandex.cloud.vpc.v1.UpdateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*\x1e\n\x14UpdateSubnetMetadata\x12\x06Subnet\x82\xd3\xe4\x93\x02 2\x1b/vpc/v1/subnets/{subnet_id}:\x01*\x12\xbd\x01\n\rAddCidrBlocks\x12/.yandex.cloud.vpc.v1.AddSubnetCidrBlocksRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1e\n\x14UpdateSubnetMetadata\x12\x06Subnet\x82\xd3\xe4\x93\x02\x30\"+/vpc/v1/subnets/{subnet_id}:add-cidr-blocks:\x01*\x12\xc6\x01\n\x10RemoveCidrBlocks\x12\x32.yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*\x1e\n\x14UpdateSubnetMetadata\x12\x06Subnet\x82\xd3\xe4\x93\x02\x33\"./vpc/v1/subnets/{subnet_id}:remove-cidr-blocks:\x01*\x12\xab\x01\n\x06\x44\x65lete\x12(.yandex.cloud.vpc.v1.DeleteSubnetRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*-\n\x14\x44\x65leteSubnetMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1d*\x1b/vpc/v1/subnets/{subnet_id}\x12\xa5\x01\n\x0eListOperations\x12\x30.yandex.cloud.vpc.v1.ListSubnetOperationsRequest\x1a\x31.yandex.cloud.vpc.v1.ListSubnetOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/vpc/v1/subnets/{subnet_id}/operations\x12\x9e\x01\n\x04Move\x12&.yandex.cloud.vpc.v1.MoveSubnetRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*\x1c\n\x12MoveSubnetMetadata\x12\x06Subnet\x82\xd3\xe4\x93\x02%\" /vpc/v1/subnets/{subnet_id}:move:\x01*\x12\xae\x01\n\x08Relocate\x12*.yandex.cloud.vpc.v1.RelocateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2* \n\x16RelocateSubnetMetadata\x12\x06Subnet\x82\xd3\xe4\x93\x02)\"$/vpc/v1/subnets/{subnet_id}:relocate:\x01*\x12\xa1\x01\n\x11ListUsedAddresses\x12-.yandex.cloud.vpc.v1.ListUsedAddressesRequest\x1a..yandex.cloud.vpc.v1.ListUsedAddressesResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/vpc/v1/subnets/{subnet_id}/addressesBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.subnet_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _GETSUBNETREQUEST.fields_by_name['subnet_id']._options = None
  _GETSUBNETREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSUBNETSREQUEST.fields_by_name['folder_id']._options = None
  _LISTSUBNETSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSUBNETSREQUEST.fields_by_name['page_size']._options = None
  _LISTSUBNETSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSUBNETSREQUEST.fields_by_name['page_token']._options = None
  _LISTSUBNETSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTSUBNETSREQUEST.fields_by_name['filter']._options = None
  _LISTSUBNETSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATESUBNETREQUEST_LABELSENTRY._options = None
  _CREATESUBNETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESUBNETREQUEST.fields_by_name['folder_id']._options = None
  _CREATESUBNETREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESUBNETREQUEST.fields_by_name['name']._options = None
  _CREATESUBNETREQUEST.fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _CREATESUBNETREQUEST.fields_by_name['description']._options = None
  _CREATESUBNETREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATESUBNETREQUEST.fields_by_name['labels']._options = None
  _CREATESUBNETREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATESUBNETREQUEST.fields_by_name['network_id']._options = None
  _CREATESUBNETREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESUBNETREQUEST.fields_by_name['zone_id']._options = None
  _CREATESUBNETREQUEST.fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESUBNETREQUEST.fields_by_name['v4_cidr_blocks']._options = None
  _CREATESUBNETREQUEST.fields_by_name['v4_cidr_blocks']._serialized_options = b'\350\3071\001'
  _CREATESUBNETREQUEST.fields_by_name['route_table_id']._options = None
  _CREATESUBNETREQUEST.fields_by_name['route_table_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATESUBNETREQUEST_LABELSENTRY._options = None
  _UPDATESUBNETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESUBNETREQUEST.fields_by_name['subnet_id']._options = None
  _UPDATESUBNETREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESUBNETREQUEST.fields_by_name['name']._options = None
  _UPDATESUBNETREQUEST.fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _UPDATESUBNETREQUEST.fields_by_name['description']._options = None
  _UPDATESUBNETREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATESUBNETREQUEST.fields_by_name['labels']._options = None
  _UPDATESUBNETREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATESUBNETREQUEST.fields_by_name['route_table_id']._options = None
  _UPDATESUBNETREQUEST.fields_by_name['route_table_id']._serialized_options = b'\212\3101\004<=50'
  _ADDSUBNETCIDRBLOCKSREQUEST.fields_by_name['subnet_id']._options = None
  _ADDSUBNETCIDRBLOCKSREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REMOVESUBNETCIDRBLOCKSREQUEST.fields_by_name['subnet_id']._options = None
  _REMOVESUBNETCIDRBLOCKSREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETESUBNETREQUEST.fields_by_name['subnet_id']._options = None
  _DELETESUBNETREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSUBNETOPERATIONSREQUEST.fields_by_name['subnet_id']._options = None
  _LISTSUBNETOPERATIONSREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSUBNETOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTSUBNETOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSUBNETOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTSUBNETOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _MOVESUBNETREQUEST.fields_by_name['subnet_id']._options = None
  _MOVESUBNETREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVESUBNETREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVESUBNETREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTUSEDADDRESSESREQUEST.fields_by_name['subnet_id']._options = None
  _LISTUSEDADDRESSESREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001'
  _RELOCATESUBNETREQUEST.fields_by_name['subnet_id']._options = None
  _RELOCATESUBNETREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RELOCATESUBNETREQUEST.fields_by_name['destination_zone_id']._options = None
  _RELOCATESUBNETREQUEST.fields_by_name['destination_zone_id']._serialized_options = b'\350\3071\001'
  _SUBNETSERVICE.methods_by_name['Get']._options = None
  _SUBNETSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/vpc/v1/subnets/{subnet_id}'
  _SUBNETSERVICE.methods_by_name['List']._options = None
  _SUBNETSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/vpc/v1/subnets'
  _SUBNETSERVICE.methods_by_name['Create']._options = None
  _SUBNETSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateSubnetMetadata\022\006Subnet\202\323\344\223\002\024\"\017/vpc/v1/subnets:\001*'
  _SUBNETSERVICE.methods_by_name['Update']._options = None
  _SUBNETSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateSubnetMetadata\022\006Subnet\202\323\344\223\002 2\033/vpc/v1/subnets/{subnet_id}:\001*'
  _SUBNETSERVICE.methods_by_name['AddCidrBlocks']._options = None
  _SUBNETSERVICE.methods_by_name['AddCidrBlocks']._serialized_options = b'\262\322*\036\n\024UpdateSubnetMetadata\022\006Subnet\202\323\344\223\0020\"+/vpc/v1/subnets/{subnet_id}:add-cidr-blocks:\001*'
  _SUBNETSERVICE.methods_by_name['RemoveCidrBlocks']._options = None
  _SUBNETSERVICE.methods_by_name['RemoveCidrBlocks']._serialized_options = b'\262\322*\036\n\024UpdateSubnetMetadata\022\006Subnet\202\323\344\223\0023\"./vpc/v1/subnets/{subnet_id}:remove-cidr-blocks:\001*'
  _SUBNETSERVICE.methods_by_name['Delete']._options = None
  _SUBNETSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteSubnetMetadata\022\025google.protobuf.Empty\202\323\344\223\002\035*\033/vpc/v1/subnets/{subnet_id}'
  _SUBNETSERVICE.methods_by_name['ListOperations']._options = None
  _SUBNETSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002(\022&/vpc/v1/subnets/{subnet_id}/operations'
  _SUBNETSERVICE.methods_by_name['Move']._options = None
  _SUBNETSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\034\n\022MoveSubnetMetadata\022\006Subnet\202\323\344\223\002%\" /vpc/v1/subnets/{subnet_id}:move:\001*'
  _SUBNETSERVICE.methods_by_name['Relocate']._options = None
  _SUBNETSERVICE.methods_by_name['Relocate']._serialized_options = b'\262\322* \n\026RelocateSubnetMetadata\022\006Subnet\202\323\344\223\002)\"$/vpc/v1/subnets/{subnet_id}:relocate:\001*'
  _SUBNETSERVICE.methods_by_name['ListUsedAddresses']._options = None
  _SUBNETSERVICE.methods_by_name['ListUsedAddresses']._serialized_options = b'\202\323\344\223\002\'\022%/vpc/v1/subnets/{subnet_id}/addresses'
  _globals['_GETSUBNETREQUEST']._serialized_start=308
  _globals['_GETSUBNETREQUEST']._serialized_end=359
  _globals['_LISTSUBNETSREQUEST']._serialized_start=362
  _globals['_LISTSUBNETSREQUEST']._serialized_end=505
  _globals['_LISTSUBNETSRESPONSE']._serialized_start=507
  _globals['_LISTSUBNETSRESPONSE']._serialized_end=599
  _globals['_CREATESUBNETREQUEST']._serialized_start=602
  _globals['_CREATESUBNETREQUEST']._serialized_end=1120
  _globals['_CREATESUBNETREQUEST_LABELSENTRY']._serialized_start=1069
  _globals['_CREATESUBNETREQUEST_LABELSENTRY']._serialized_end=1114
  _globals['_CREATESUBNETMETADATA']._serialized_start=1122
  _globals['_CREATESUBNETMETADATA']._serialized_end=1163
  _globals['_UPDATESUBNETREQUEST']._serialized_start=1166
  _globals['_UPDATESUBNETREQUEST']._serialized_end=1656
  _globals['_UPDATESUBNETREQUEST_LABELSENTRY']._serialized_start=1069
  _globals['_UPDATESUBNETREQUEST_LABELSENTRY']._serialized_end=1114
  _globals['_UPDATESUBNETMETADATA']._serialized_start=1658
  _globals['_UPDATESUBNETMETADATA']._serialized_end=1699
  _globals['_ADDSUBNETCIDRBLOCKSREQUEST']._serialized_start=1701
  _globals['_ADDSUBNETCIDRBLOCKSREQUEST']._serialized_end=1786
  _globals['_ADDSUBNETCIDRBLOCKSMETADATA']._serialized_start=1788
  _globals['_ADDSUBNETCIDRBLOCKSMETADATA']._serialized_end=1836
  _globals['_REMOVESUBNETCIDRBLOCKSREQUEST']._serialized_start=1838
  _globals['_REMOVESUBNETCIDRBLOCKSREQUEST']._serialized_end=1926
  _globals['_REMOVESUBNETCIDRBLOCKSMETADATA']._serialized_start=1928
  _globals['_REMOVESUBNETCIDRBLOCKSMETADATA']._serialized_end=1979
  _globals['_DELETESUBNETREQUEST']._serialized_start=1981
  _globals['_DELETESUBNETREQUEST']._serialized_end=2035
  _globals['_DELETESUBNETMETADATA']._serialized_start=2037
  _globals['_DELETESUBNETMETADATA']._serialized_end=2078
  _globals['_LISTSUBNETOPERATIONSREQUEST']._serialized_start=2080
  _globals['_LISTSUBNETOPERATIONSREQUEST']._serialized_end=2204
  _globals['_LISTSUBNETOPERATIONSRESPONSE']._serialized_start=2206
  _globals['_LISTSUBNETOPERATIONSRESPONSE']._serialized_end=2316
  _globals['_MOVESUBNETREQUEST']._serialized_start=2318
  _globals['_MOVESUBNETREQUEST']._serialized_end=2415
  _globals['_MOVESUBNETMETADATA']._serialized_start=2417
  _globals['_MOVESUBNETMETADATA']._serialized_end=2456
  _globals['_LISTUSEDADDRESSESREQUEST']._serialized_start=2458
  _globals['_LISTUSEDADDRESSESREQUEST']._serialized_end=2564
  _globals['_LISTUSEDADDRESSESRESPONSE']._serialized_start=2566
  _globals['_LISTUSEDADDRESSESRESPONSE']._serialized_end=2671
  _globals['_USEDADDRESS']._serialized_start=2674
  _globals['_USEDADDRESS']._serialized_end=2811
  _globals['_RELOCATESUBNETREQUEST']._serialized_start=2813
  _globals['_RELOCATESUBNETREQUEST']._serialized_end=2904
  _globals['_RELOCATESUBNETMETADATA']._serialized_start=2906
  _globals['_RELOCATESUBNETMETADATA']._serialized_end=2949
  _globals['_SUBNETSERVICE']._serialized_start=2952
  _globals['_SUBNETSERVICE']._serialized_end=4744
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.compute.v1.hardware_generation_pb2
import yandex.cloud.compute.v1.kek_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Image(google.protobuf.message.Message):
    """An Image resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Image._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Image._Status.ValueType  # 0
        CREATING: Image._Status.ValueType  # 1
        """Image is being created."""
        READY: Image._Status.ValueType  # 2
        """Image is ready to use."""
        ERROR: Image._Status.ValueType  # 3
        """Image encountered a problem and cannot operate."""
        DELETING: Image._Status.ValueType  # 4
        """Image is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Image.Status.ValueType  # 0
    CREATING: Image.Status.ValueType  # 1
    """Image is being created."""
    READY: Image.Status.ValueType  # 2
    """Image is ready to use."""
    ERROR: Image.Status.ValueType  # 3
    """Image encountered a problem and cannot operate."""
    DELETING: Image.Status.ValueType  # 4
    """Image is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    STORAGE_SIZE_FIELD_NUMBER: builtins.int
    MIN_DISK_SIZE_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    POOLED_FIELD_NUMBER: builtins.int
    HARDWARE_GENERATION_FIELD_NUMBER: builtins.int
    KMS_KEY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the image."""
    folder_id: builtins.str
    """ID of the folder that the image belongs to."""
    name: builtins.str
    """Name of the image. 1-63 characters long."""
    description: builtins.str
    """Description of the image. 0-256 characters long."""
    family: builtins.str
    """The name of the image family to which this image belongs.

    You can get the most recent image from a family by using
    the [yandex.cloud.compute.v1.ImageService.GetLatestByFamily] request
    and create the disk from this image.
    """
    storage_size: builtins.int
    """The size of the image, specified in bytes."""
    min_disk_size: builtins.int
    """Minimum size of the disk which will be created from this image."""
    status: global___Image.Status.ValueType
    """Current status of the image."""
    pooled: builtins.bool
    """When true, indicates there is an image pool for fast creation disks from the image."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to this resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.

        The correct license ID is generated by the platform. IDs are inherited by new resources created from this resource.

        If you know the license IDs, specify them when you create the image.
        For example, if you create a disk image using a third-party utility and load it into Object Storage, the license IDs will be lost.
        You can specify them in the [yandex.cloud.compute.v1.ImageService.Create] request.
        """

    @property
    def os(self) -> global___Os:
        """Operating system that is contained in the image."""

    @property
    def hardware_generation(self) -> yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration:
        """If specified, forces the same HardwareGeneration features to be applied to the instance
        created using this image as a source for the boot disk. Otherwise the current default will be used.
        """

    @property
    def kms_key(self) -> yandex.cloud.compute.v1.kek_pb2.KMSKey:
        """Key encryption key info."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        family: builtins.str = ...,
        storage_size: builtins.int = ...,
        min_disk_size: builtins.int = ...,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
        status: global___Image.Status.ValueType = ...,
        os: global___Os | None = ...,
        pooled: builtins.bool = ...,
        hardware_generation: yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration | None = ...,
        kms_key: yandex.cloud.compute.v1.kek_pb2.KMSKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "hardware_generation", b"hardware_generation", "kms_key", b"kms_key", "os", b"os"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "family", b"family", "folder_id", b"folder_id", "hardware_generation", b"hardware_generation", "id", b"id", "kms_key", b"kms_key", "labels", b"labels", "min_disk_size", b"min_disk_size", "name", b"name", "os", b"os", "pooled", b"pooled", "product_ids", b"product_ids", "status", b"status", "storage_size", b"storage_size"]) -> None: ...

global___Image = Image

@typing.final
class Os(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Os._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Os._Type.ValueType  # 0
        LINUX: Os._Type.ValueType  # 1
        """Linux operating system."""
        WINDOWS: Os._Type.ValueType  # 2
        """Windows operating system."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Os.Type.ValueType  # 0
    LINUX: Os.Type.ValueType  # 1
    """Linux operating system."""
    WINDOWS: Os.Type.ValueType  # 2
    """Windows operating system."""

    TYPE_FIELD_NUMBER: builtins.int
    type: global___Os.Type.ValueType
    """Operating system type. The default is `LINUX`.

    This field is used to correctly emulate a vCPU and calculate the cost of using an instance.
    """
    def __init__(
        self,
        *,
        type: global___Os.Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

global___Os = Os



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iot.devices.v1.registry_data_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RegistryDataServiceStub:
    """A set of methods to work with IoT Core messages on behalf of registry"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Publish: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_data_service_pb2.PublishRegistryDataRequest,
        yandex.cloud.iot.devices.v1.registry_data_service_pb2.PublishRegistryDataResponse,
    ]
    """Publishes message on behalf of specified registry"""

class RegistryDataServiceAsyncStub:
    """A set of methods to work with IoT Core messages on behalf of registry"""

    Publish: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_data_service_pb2.PublishRegistryDataRequest,
        yandex.cloud.iot.devices.v1.registry_data_service_pb2.PublishRegistryDataResponse,
    ]
    """Publishes message on behalf of specified registry"""

class RegistryDataServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods to work with IoT Core messages on behalf of registry"""

    @abc.abstractmethod
    def Publish(
        self,
        request: yandex.cloud.iot.devices.v1.registry_data_service_pb2.PublishRegistryDataRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_data_service_pb2.PublishRegistryDataResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_data_service_pb2.PublishRegistryDataResponse]]:
        """Publishes message on behalf of specified registry"""

def add_RegistryDataServiceServicer_to_server(servicer: RegistryDataServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Repository(google.protobuf.message.Message):
    """A Repository resource. For more information, see [Repository](/docs/container-registry/concepts/repository)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the repository.
    The name is unique within the registry.
    """
    id: builtins.str
    """Output only. ID of the repository."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Repository = Repository



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.loadtesting.api.v1.common.quantiles_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Aggregation:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AggregationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Aggregation.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AGGREGATION_UNSPECIFIED: _Aggregation.ValueType  # 0
    """Unspecified."""
    AGGREGATION_MIN: _Aggregation.ValueType  # 1
    """Minimum."""
    AGGREGATION_MAX: _Aggregation.ValueType  # 2
    """Maximum."""
    AGGREGATION_AVG: _Aggregation.ValueType  # 4
    """Average."""
    AGGREGATION_MEDIAN: _Aggregation.ValueType  # 5
    """Median."""
    AGGREGATION_STD_DEV: _Aggregation.ValueType  # 6
    """Standard deviation."""

class Aggregation(_Aggregation, metaclass=_AggregationEnumTypeWrapper):
    """Aggregation function."""

AGGREGATION_UNSPECIFIED: Aggregation.ValueType  # 0
"""Unspecified."""
AGGREGATION_MIN: Aggregation.ValueType  # 1
"""Minimum."""
AGGREGATION_MAX: Aggregation.ValueType  # 2
"""Maximum."""
AGGREGATION_AVG: Aggregation.ValueType  # 4
"""Average."""
AGGREGATION_MEDIAN: Aggregation.ValueType  # 5
"""Median."""
AGGREGATION_STD_DEV: Aggregation.ValueType  # 6
"""Standard deviation."""
global___Aggregation = Aggregation

class _Comparison:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ComparisonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Comparison.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMPARISON_UNSPECIFIED: _Comparison.ValueType  # 0
    """Unspecified."""
    COMPARISON_LT: _Comparison.ValueType  # 1
    """Less than the specified value."""
    COMPARISON_LTE: _Comparison.ValueType  # 2
    """Less than or equal to the specified value."""
    COMPARISON_GT: _Comparison.ValueType  # 3
    """Greater than the specified value."""
    COMPARISON_GTE: _Comparison.ValueType  # 4
    """Greater than or equal to the specified value."""

class Comparison(_Comparison, metaclass=_ComparisonEnumTypeWrapper):
    """Comparison operator."""

COMPARISON_UNSPECIFIED: Comparison.ValueType  # 0
"""Unspecified."""
COMPARISON_LT: Comparison.ValueType  # 1
"""Less than the specified value."""
COMPARISON_LTE: Comparison.ValueType  # 2
"""Less than or equal to the specified value."""
COMPARISON_GT: Comparison.ValueType  # 3
"""Greater than the specified value."""
COMPARISON_GTE: Comparison.ValueType  # 4
"""Greater than or equal to the specified value."""
global___Comparison = Comparison

@typing.final
class Kpi(google.protobuf.message.Message):
    """KPI (Key Performance Indicator) represents some integral indicator measured during test."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTOR_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    @property
    def selector(self) -> global___KpiSelector:
        """Kind of KPI."""

    @property
    def threshold(self) -> global___KpiThreshold:
        """A condition that should be specified."""

    def __init__(
        self,
        *,
        selector: global___KpiSelector | None = ...,
        threshold: global___KpiThreshold | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["selector", b"selector", "threshold", b"threshold"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["selector", b"selector", "threshold", b"threshold"]) -> None: ...

global___Kpi = Kpi

@typing.final
class KpiThreshold(google.protobuf.message.Message):
    """KPI threshold represents a condition that an actual value of test's KPI should satisfy."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    COMPARISON_FIELD_NUMBER: builtins.int
    value: builtins.float
    """Value for comparison with an actual KPI value."""
    comparison: global___Comparison.ValueType
    """Comparison operator for comparing actual with the threshold value.

    Rule: actual (</<=/>/>=) reference
    """
    def __init__(
        self,
        *,
        value: builtins.float = ...,
        comparison: global___Comparison.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["comparison", b"comparison", "value", b"value"]) -> None: ...

global___KpiThreshold = KpiThreshold

@typing.final
class KpiSelector(google.protobuf.message.Message):
    """KPI selector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ResponseTime(google.protobuf.message.Message):
        """Response time."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        QUANTILE_FIELD_NUMBER: builtins.int
        quantile: yandex.cloud.loadtesting.api.v1.common.quantiles_pb2.QuantileType.ValueType
        """Cummulative quantile (percentile)."""
        def __init__(
            self,
            *,
            quantile: yandex.cloud.loadtesting.api.v1.common.quantiles_pb2.QuantileType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["quantile", b"quantile"]) -> None: ...

    @typing.final
    class Instances(google.protobuf.message.Message):
        """Aggregated number of instances."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AGG_FIELD_NUMBER: builtins.int
        agg: global___Aggregation.ValueType
        """Aggregation function."""
        def __init__(
            self,
            *,
            agg: global___Aggregation.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["agg", b"agg"]) -> None: ...

    @typing.final
    class ImbalanceRps(google.protobuf.message.Message):
        """Imbalance RPS."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class ProtocolCodesAbsolute(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CODES_PATTERNS_FIELD_NUMBER: builtins.int
        @property
        def codes_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Protocol (HTTP, GRPC) code patterns to match.

            All successful HTTP responses: ['2xx', '3xx'].
            All failed HTTP responses: ['0', '4xx', '5xx'].
            """

        def __init__(
            self,
            *,
            codes_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["codes_patterns", b"codes_patterns"]) -> None: ...

    @typing.final
    class ProtocolCodesRelative(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CODES_PATTERNS_FIELD_NUMBER: builtins.int
        @property
        def codes_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Protocol (HTTP, GRPC) code patterns to match.

            All successful HTTP responses: ['2xx', '3xx'].
            All failed HTTP responses: ['0', '4xx', '5xx'].
            """

        def __init__(
            self,
            *,
            codes_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["codes_patterns", b"codes_patterns"]) -> None: ...

    @typing.final
    class NetworkCodesAbsolute(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CODES_PATTERNS_FIELD_NUMBER: builtins.int
        @property
        def codes_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Network code patterns to match.

            All successful network responses: ['0'].
            All failed network responses: ['xx', 'xxx'].
            """

        def __init__(
            self,
            *,
            codes_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["codes_patterns", b"codes_patterns"]) -> None: ...

    @typing.final
    class NetworkCodesRelative(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CODES_PATTERNS_FIELD_NUMBER: builtins.int
        @property
        def codes_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Network code patterns to match.

            All successful network responses: ['0'].
            All failed network responses: ['xx', 'xxx'].
            """

        def __init__(
            self,
            *,
            codes_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["codes_patterns", b"codes_patterns"]) -> None: ...

    RESPONSE_TIME_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    IMBALANCE_RPS_FIELD_NUMBER: builtins.int
    PROTOCOL_CODES_ABSOLUTE_FIELD_NUMBER: builtins.int
    PROTOCOL_CODES_RELATIVE_FIELD_NUMBER: builtins.int
    NETWORK_CODES_ABSOLUTE_FIELD_NUMBER: builtins.int
    NETWORK_CODES_RELATIVE_FIELD_NUMBER: builtins.int
    @property
    def response_time(self) -> global___KpiSelector.ResponseTime:
        """Response time cummulative quantile (percentile)."""

    @property
    def instances(self) -> global___KpiSelector.Instances:
        """A number of instances throughout the test."""

    @property
    def imbalance_rps(self) -> global___KpiSelector.ImbalanceRps:
        """An RPS at the moment the test has been auto-stopped."""

    @property
    def protocol_codes_absolute(self) -> global___KpiSelector.ProtocolCodesAbsolute:
        """A total number of requests completed with certain protocol (HTTP, GRPC, etc.) codes."""

    @property
    def protocol_codes_relative(self) -> global___KpiSelector.ProtocolCodesRelative:
        """A percentage of requests completed with certain protocol (HTTP, GRPC, etc.) codes."""

    @property
    def network_codes_absolute(self) -> global___KpiSelector.NetworkCodesAbsolute:
        """A total number of requests completed with certain network codes."""

    @property
    def network_codes_relative(self) -> global___KpiSelector.NetworkCodesRelative:
        """A percentage of requests completed with certain network codes."""

    def __init__(
        self,
        *,
        response_time: global___KpiSelector.ResponseTime | None = ...,
        instances: global___KpiSelector.Instances | None = ...,
        imbalance_rps: global___KpiSelector.ImbalanceRps | None = ...,
        protocol_codes_absolute: global___KpiSelector.ProtocolCodesAbsolute | None = ...,
        protocol_codes_relative: global___KpiSelector.ProtocolCodesRelative | None = ...,
        network_codes_absolute: global___KpiSelector.NetworkCodesAbsolute | None = ...,
        network_codes_relative: global___KpiSelector.NetworkCodesRelative | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["imbalance_rps", b"imbalance_rps", "instances", b"instances", "kind", b"kind", "network_codes_absolute", b"network_codes_absolute", "network_codes_relative", b"network_codes_relative", "protocol_codes_absolute", b"protocol_codes_absolute", "protocol_codes_relative", b"protocol_codes_relative", "response_time", b"response_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["imbalance_rps", b"imbalance_rps", "instances", b"instances", "kind", b"kind", "network_codes_absolute", b"network_codes_absolute", "network_codes_relative", b"network_codes_relative", "protocol_codes_absolute", b"protocol_codes_absolute", "protocol_codes_relative", b"protocol_codes_relative", "response_time", b"response_time"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["kind", b"kind"]) -> typing.Literal["response_time", "instances", "imbalance_rps", "protocol_codes_absolute", "protocol_codes_relative", "network_codes_absolute", "network_codes_relative"] | None: ...

global___KpiSelector = KpiSelector



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.type.timeofday_pb2
import sys
import typing
import yandex.cloud.mdb.sqlserver.v1.config.sqlserver2016sp2_pb2
import yandex.cloud.mdb.sqlserver.v1.config.sqlserver2017_pb2
import yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """An SQL Server cluster.

    For more information, see the [Concepts](/docs/managed-sqlserver/concepts) section of the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy: only hotfixes are applied during regular maintenance."""
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with more aggressive update policy: new versions are rolled out irrespective of backward compatibility."""

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy: only hotfixes are applied during regular maintenance."""
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with more aggressive update policy: new versions are rolled out irrespective of backward compatibility."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """State of the cluster is unknown ([Host.health] of all hosts in the cluster is `UNKNOWN`)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and works well ([Host.health] of all hosts in the cluster is `ALIVE`)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] of all hosts in the cluster is `DEAD`)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is in degraded state ([Host.health] of at least one of the hosts in the cluster is not `ALIVE`)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """State of the cluster is unknown ([Host.health] of all hosts in the cluster is `UNKNOWN`)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and works well ([Host.health] of all hosts in the cluster is `ALIVE`)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] of all hosts in the cluster is `DEAD`)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is in degraded state ([Host.health] of at least one of the hosts in the cluster is not `ALIVE`)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SQLCOLLATION_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the SQL Server cluster.

    This ID is assigned by Managed Service for SQL Server at the moment of creation.
    """
    folder_id: builtins.str
    """ID of the folder the SQL Server cluster belongs to."""
    name: builtins.str
    """Name of the SQL Server cluster.

    The name must be unique within the folder, comply with [RFC 1035](https://www.ietf.org/rfc/rfc1035.txt) and be 1-63 characters long.
    """
    description: builtins.str
    """Description of the SQL Server cluster.

    Must be 0-256 characters long.
    """
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the SQL Server cluster."""
    network_id: builtins.str
    """ID of the network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    sqlcollation: builtins.str
    """SQL Server Collation."""
    service_account_id: builtins.str
    """ID of the service account which is used for access to Object Storage."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when SQL Server cluster was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the SQL Server cluster as `key:value` pairs.

        Maximum 64 per resource.
        """

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the SQL Server cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the SQL Server cluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the cluster."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        sqlcollation: builtins.str = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "host_group_ids", b"host_group_ids", "id", b"id", "labels", b"labels", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "sqlcollation", b"sqlcollation", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the SQL Server cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SecondaryConnections:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SecondaryConnectionsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterConfig._SecondaryConnections.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SECONDARY_CONNECTIONS_UNSPECIFIED: ClusterConfig._SecondaryConnections.ValueType  # 0
        SECONDARY_CONNECTIONS_OFF: ClusterConfig._SecondaryConnections.ValueType  # 1
        """Connections to secondary replicas are prohibited"""
        SECONDARY_CONNECTIONS_READ_ONLY: ClusterConfig._SecondaryConnections.ValueType  # 2
        """Secondary replicas are read-only"""

    class SecondaryConnections(_SecondaryConnections, metaclass=_SecondaryConnectionsEnumTypeWrapper): ...
    SECONDARY_CONNECTIONS_UNSPECIFIED: ClusterConfig.SecondaryConnections.ValueType  # 0
    SECONDARY_CONNECTIONS_OFF: ClusterConfig.SecondaryConnections.ValueType  # 1
    """Connections to secondary replicas are prohibited"""
    SECONDARY_CONNECTIONS_READ_ONLY: ClusterConfig.SecondaryConnections.ValueType  # 2
    """Secondary replicas are read-only"""

    VERSION_FIELD_NUMBER: builtins.int
    SQLSERVER_CONFIG_2016SP2STD_FIELD_NUMBER: builtins.int
    SQLSERVER_CONFIG_2016SP2ENT_FIELD_NUMBER: builtins.int
    SQLSERVER_CONFIG_2017STD_FIELD_NUMBER: builtins.int
    SQLSERVER_CONFIG_2017ENT_FIELD_NUMBER: builtins.int
    SQLSERVER_CONFIG_2019STD_FIELD_NUMBER: builtins.int
    SQLSERVER_CONFIG_2019ENT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    BACKUP_WINDOW_START_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    SECONDARY_CONNECTIONS_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of the SQL Server."""
    secondary_connections: global___ClusterConfig.SecondaryConnections.ValueType
    """Secondary replicas connection mode"""
    @property
    def sqlserver_config_2016sp2std(self) -> yandex.cloud.mdb.sqlserver.v1.config.sqlserver2016sp2_pb2.SQLServerConfigSet2016sp2std:
        """Configuration of the SQL Server 2016sp2 standard edition instance."""

    @property
    def sqlserver_config_2016sp2ent(self) -> yandex.cloud.mdb.sqlserver.v1.config.sqlserver2016sp2_pb2.SQLServerConfigSet2016sp2ent:
        """Configuration of the SQL Server 2016sp2 enterprise edition instance."""

    @property
    def sqlserver_config_2017std(self) -> yandex.cloud.mdb.sqlserver.v1.config.sqlserver2017_pb2.SQLServerConfigSet2017std:
        """Configuration of the SQL Server 2017 standard edition instance."""

    @property
    def sqlserver_config_2017ent(self) -> yandex.cloud.mdb.sqlserver.v1.config.sqlserver2017_pb2.SQLServerConfigSet2017ent:
        """Configuration of the SQL Server 2017 enterprise edition instance."""

    @property
    def sqlserver_config_2019std(self) -> yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2.SQLServerConfigSet2019std:
        """Configuration of the SQL Server 2019 standard edition instance."""

    @property
    def sqlserver_config_2019ent(self) -> yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2.SQLServerConfigSet2019ent:
        """Configuration of the SQL Server 2019 enterprise edition instance."""

    @property
    def resources(self) -> global___Resources:
        """Resources allocated to SQL Server hosts."""

    @property
    def backup_window_start(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Start time for the daily backup in UTC timezone."""

    @property
    def access(self) -> global___Access:
        """Database access policy."""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        sqlserver_config_2016sp2std: yandex.cloud.mdb.sqlserver.v1.config.sqlserver2016sp2_pb2.SQLServerConfigSet2016sp2std | None = ...,
        sqlserver_config_2016sp2ent: yandex.cloud.mdb.sqlserver.v1.config.sqlserver2016sp2_pb2.SQLServerConfigSet2016sp2ent | None = ...,
        sqlserver_config_2017std: yandex.cloud.mdb.sqlserver.v1.config.sqlserver2017_pb2.SQLServerConfigSet2017std | None = ...,
        sqlserver_config_2017ent: yandex.cloud.mdb.sqlserver.v1.config.sqlserver2017_pb2.SQLServerConfigSet2017ent | None = ...,
        sqlserver_config_2019std: yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2.SQLServerConfigSet2019std | None = ...,
        sqlserver_config_2019ent: yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2.SQLServerConfigSet2019ent | None = ...,
        resources: global___Resources | None = ...,
        backup_window_start: google.type.timeofday_pb2.TimeOfDay | None = ...,
        access: global___Access | None = ...,
        secondary_connections: global___ClusterConfig.SecondaryConnections.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "backup_window_start", b"backup_window_start", "resources", b"resources", "sqlserver_config", b"sqlserver_config", "sqlserver_config_2016sp2ent", b"sqlserver_config_2016sp2ent", "sqlserver_config_2016sp2std", b"sqlserver_config_2016sp2std", "sqlserver_config_2017ent", b"sqlserver_config_2017ent", "sqlserver_config_2017std", b"sqlserver_config_2017std", "sqlserver_config_2019ent", b"sqlserver_config_2019ent", "sqlserver_config_2019std", b"sqlserver_config_2019std"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "backup_window_start", b"backup_window_start", "resources", b"resources", "secondary_connections", b"secondary_connections", "sqlserver_config", b"sqlserver_config", "sqlserver_config_2016sp2ent", b"sqlserver_config_2016sp2ent", "sqlserver_config_2016sp2std", b"sqlserver_config_2016sp2std", "sqlserver_config_2017ent", b"sqlserver_config_2017ent", "sqlserver_config_2017std", b"sqlserver_config_2017std", "sqlserver_config_2019ent", b"sqlserver_config_2019ent", "sqlserver_config_2019std", b"sqlserver_config_2019std", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sqlserver_config", b"sqlserver_config"]) -> typing.Literal["sqlserver_config_2016sp2std", "sqlserver_config_2016sp2ent", "sqlserver_config_2017std", "sqlserver_config_2017ent", "sqlserver_config_2019std", "sqlserver_config_2019ent"] | None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class Host(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Role:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Role.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ROLE_UNKNOWN: Host._Role.ValueType  # 0
        """Role of the host in the cluster is unknown."""
        MASTER: Host._Role.ValueType  # 1
        """Host is the master SQL Server instance in the cluster."""
        REPLICA: Host._Role.ValueType  # 2
        """Host is a replica SQL Server instance in the cluster."""

    class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...
    ROLE_UNKNOWN: Host.Role.ValueType  # 0
    """Role of the host in the cluster is unknown."""
    MASTER: Host.Role.ValueType  # 1
    """Host is the master SQL Server instance in the cluster."""
    REPLICA: Host.Role.ValueType  # 2
    """Host is a replica SQL Server instance in the cluster."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is degraded and can perform only some of its essential functions."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is degraded and can perform only some of its essential functions."""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SQL Server host.

    The host name is assigned by Managed Service for SQL Server at the moment of creation and cannot be changed. 1-63 characters long.

    The name is unique across all database hosts that exist on the platform as it defines the FQDN of the host.
    """
    cluster_id: builtins.str
    """ID of the SQL Server host.

    The ID is assigned by Managed Service for SQL Server at the moment of creation.
    """
    zone_id: builtins.str
    """ID of the availability zone where the SQL Server host resides."""
    role: global___Host.Role.ValueType
    """Role of the host in the cluster."""
    health: global___Host.Health.ValueType
    """Status code of the aggregated health of the host."""
    subnet_id: builtins.str
    """ID of the subnet that the host belongs to."""
    assign_public_ip: builtins.bool
    """Flag showing public IP assignment status to this host."""
    @property
    def resources(self) -> global___Resources:
        """Resources allocated to the host."""

    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]:
        """Services provided by the host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        resources: global___Resources | None = ...,
        role: global___Host.Role.ValueType = ...,
        health: global___Host.Health.ValueType = ...,
        services: collections.abc.Iterable[global___Service] | None = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "resources", b"resources", "role", b"role", "services", b"services", "subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Service._Type.ValueType  # 0
        SQLSERVER: Service._Type.ValueType  # 1
        """SQL Server service."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Service.Type.ValueType  # 0
    SQLSERVER: Service.Type.ValueType  # 1
    """SQL Server service."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Service._Health.ValueType  # 0
        """Health of the server is unknown."""
        ALIVE: Service._Health.ValueType  # 1
        """The server is working normally."""
        DEAD: Service._Health.ValueType  # 2
        """The server is dead or unresponsive."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Service.Health.ValueType  # 0
    """Health of the server is unknown."""
    ALIVE: Service.Health.ValueType  # 1
    """The server is working normally."""
    DEAD: Service.Health.ValueType  # 2
    """The server is dead or unresponsive."""

    TYPE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    type: global___Service.Type.ValueType
    """Type of the service provided by the host."""
    health: global___Service.Health.ValueType
    """Status code of server availability."""
    def __init__(
        self,
        *,
        type: global___Service.Type.ValueType = ...,
        health: global___Service.Health.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["health", b"health", "type", b"type"]) -> None: ...

global___Service = Service

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to a host (CPU, memory, etc.).

    All available presets are listed in the [documentation](/docs/managed-sqlserver/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage available to a host."""
    disk_type_id: builtins.str
    """Type of the storage environment for the host.

    Possible values:
    * `network-hdd` - network HDD drive;
    * `network-ssd` - network SSD drive;
    * `local-ssd` - local SSD storage.
    """
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class Access(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_LENS_FIELD_NUMBER: builtins.int
    WEB_SQL_FIELD_NUMBER: builtins.int
    data_lens: builtins.bool
    """Allows access for DataLens."""
    web_sql: builtins.bool
    """Allows access for Web SQL."""
    def __init__(
        self,
        *,
        data_lens: builtins.bool = ...,
        web_sql: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_lens", b"data_lens", "web_sql", b"web_sql"]) -> None: ...

global___Access = Access



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.k8s.marketplace.v1.helm_release_pb2
import yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HelmReleaseServiceStub:
    """A set of methods for managing Helm release."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.ListHelmReleasesRequest,
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.ListHelmReleasesResponse,
    ]
    """Retrieves the list of Helm releases in the specified Kubernetes Cluster."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.GetHelmReleaseRequest,
        yandex.cloud.k8s.marketplace.v1.helm_release_pb2.HelmRelease,
    ]
    """Returns the specified Helm release."""

    Install: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.InstallHelmReleaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Installs helm release into specified Kubernetes Cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.UpdateHelmReleaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates helm release."""

    Uninstall: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.UninstallHelmReleaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Uninstalls helm release."""

class HelmReleaseServiceAsyncStub:
    """A set of methods for managing Helm release."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.ListHelmReleasesRequest,
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.ListHelmReleasesResponse,
    ]
    """Retrieves the list of Helm releases in the specified Kubernetes Cluster."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.GetHelmReleaseRequest,
        yandex.cloud.k8s.marketplace.v1.helm_release_pb2.HelmRelease,
    ]
    """Returns the specified Helm release."""

    Install: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.InstallHelmReleaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Installs helm release into specified Kubernetes Cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.UpdateHelmReleaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates helm release."""

    Uninstall: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.UninstallHelmReleaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Uninstalls helm release."""

class HelmReleaseServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Helm release."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.ListHelmReleasesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.ListHelmReleasesResponse, collections.abc.Awaitable[yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.ListHelmReleasesResponse]]:
        """Retrieves the list of Helm releases in the specified Kubernetes Cluster."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.GetHelmReleaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.k8s.marketplace.v1.helm_release_pb2.HelmRelease, collections.abc.Awaitable[yandex.cloud.k8s.marketplace.v1.helm_release_pb2.HelmRelease]]:
        """Returns the specified Helm release."""

    @abc.abstractmethod
    def Install(
        self,
        request: yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.InstallHelmReleaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Installs helm release into specified Kubernetes Cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.UpdateHelmReleaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates helm release."""

    @abc.abstractmethod
    def Uninstall(
        self,
        request: yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2.UninstallHelmReleaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Uninstalls helm release."""

def add_HelmReleaseServiceServicer_to_server(servicer: HelmReleaseServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
